                     function ekin
% ***************************************************************
%                    P r o g r a m   EKIN
% ***************************************************************
%
%  PURPOSE:
%    Derive differential equation of motion of a mechanical
%    system with one degree of freedom by means of the theo-
%    rem of Kinetic Energy     dEk/dt = N(t,q,qt)
%    Resolve the equation numerically and plots the graphics
%    of the coordinate, velocity and phase plane.
%    If possible, the program could solve the problem analytically.
%
%  INPUT DATA:
%    Ek   - expression of the kinetic energy Ek = Ek(q,qt);
%    N    - power of the forces and moments N = N(t,q,qt);
%    q0   - initial value of the coordinate;
%    qt0  - initial value of the velocity;
%    Tend - upper bound of the integration;
%    eps  - precision of the calculations;
%    np   - number of parameters .
%    P{1}, P{2}, ..., P{np} - names of the parameters (array of cells);
%
%  NOTES:
%   1. The coordinate is designed by the symbol 'q' and velocity by 'qt';
%   2. The physical names of the parameters are assigned to the
%      cells of the array P like this: P{1}='m', P{2}='c',...;
%   3. For analytical solution the values of Tend, eps, np and P are not
%      needed.
%   4. Initial values q0, qt0 must to be entered as strings, even though
%      they represent numbers!
%   5. All the data can be input from file or in interactive mode.
% 
%  EXAMPLE of DATA FILE:
%   % Data for problem ...
%     Ek   = '1/2*a*qt^2';
%     N    = '-(k*qt + 9.81*sin(q))*qt';
%     q0   = 'q0';  ( or q0  = '0.12';)
%     qt0  = 'qt0'; ( or qt0 = '7.5';)
%     Tend = 20;
%     eps  = 1.e-8;
%     np   = 2;
%     P{1} = 'a';
%     P{2} = 'k';