                       function lagre2
% *******************************************************************
%                      P r o g r a m    LAGRE2
% *******************************************************************
%
% PURPOSE:
%   Derive differential equations of motion of a mechanical system
%   with two degree of freedom by means of Lagrange equations
%        d/dt(dL/dqt1) - dL/dq1 = QN1(t,q1,q2,qt1,qt2); 
%        d/dt(dL/dqt2) - dL/dq2 = QN2(t,q1,q2,qt1,qt2);
%   Resolve the equations numerically and plots the graphics
%   of the coordinates, velocities and phase planes.
%
% INPUT DATA:
%    L    - xpression of the Lagrangian  L = L(t, q1, q2, qt1, qt2);
%    QN1  - generalized non potential force QN1 = QN1(t,q1,q2,qt1,qt2);
%    QN2  - generalized non potential force QN2 = QN2(t,q1,q2,qt1,qt2);
%    qj0  - vector initial values of the coordinates;
%    qtj0 - vector initial values of the velocities;
%    Tend - upper bound of the integration;
%    eps  - precision of the calculations;
%    np   - number of parameters .
%    P{1}, P{2}, ..., P{np} - names of the parameters (array of cells);
%
% NOTES:
%   1. The coordinates are designed by the symbols 'q1', 'q2'
%      and velocities by 'qt1', 'qt2';
%   2. The physical names of the parameters are assigned to the
%      cells of the array P like this: P{1}='m', P{2}='c',...;
%   3. All the data can be input from file or in interactive mode.
% 
% EXAMPLE of DATA FILE:
%  % Problem: Elliptical Pendulum
%    L = ['1/2*(m1+m2)*qt1^2 + 1/2*m2*l^2*qt2^2 + ',...
%            'm2*l*qt1*qt2*cos(q2) - 1/2*c*q1^2 + ',...
%            '9.81*m2*l*cos(q2)']; % Lagrangian
%    QN{1} = '-alfa*qt1'; % Generalized
%    QN{2} = '-k*qt2';    % non potential forces
%    qj0   = [0.02, 0];   % Initial coordinates
%    qtj0  = [0.1, 0];    % Initial velocities
%    Tend  = 20;          % Upper bound of integration
%    eps   = 1.e-8;       % Precision of computations
%    np    = 6;           % Number of parameters
%    P{1}  = 'm1';        % Name assignation of the
%    P{2}  = 'm2';        % physical parameters
%    P{3}  = 'l';
%    P{4}  = 'c';
%    P{5}  = 'alfa';
%    P{6}  = 'k';