                    function lagren
% *****************************************************************
%                   Universal Program LAGREN
% *****************************************************************
%
% PURPOSE:
%   - Derives differential equatiopns of motion of a mechanical
%     system  with arbitrary degree of freedom 's' by means of
%     LAGRANGE equations:
%        d/dt(dL/dqtj)- dL/dqj = QNj, j = 1, 2, ..., s ;
%   - Generate automatic the file-function, wich describes right-
%     hand sides of canonical differential equations system;
%   - Integrates the equations numerically and plots the graphics
%     of the coordinates, velocities and phase planes.
%     For systems with one degree of freedom, could find anaytical
%     solution, if possible.
% 
% INPUT DATE:
%   s - degree of freedom of the system;
%   L = L(t,q1,q2,...,qs,qt1,qt2,...,qts)- Lagrangian;
%   QN{j} = F(t,q1,q2,...,qs,qt1,qt2,...,qts)- generalized
%   non potential forces (array of cells), j = 1,2,...,s ;
%   np   - number of parameters;
%   P{1}, P{2}, ..., P{np} - names of the parameters (array of cells);
%   qj0  = [q10,q20,...,qs0] - vector initial coordinates;
%   qtj0 = [qt10,qt20,...,qts0] - vector initial velocities;
%   Tend - upper bound of the integration;
%   eps  - precision of the computations.
%
% NOTES:
%   1. The coordinates are designed by the symbols q1,q2,...,qs;
%   2. The velocities are designed by the symbols qt1,qt2,...,qts;
%   3. The physical names of the parameters are assigned to the
%      cells of the array P like this: P{1}='m1', P{2}='alfa',...;
%   4. All the data can be input from file or in interactive mode;
%   5. If, for a mechanical system with 1 degre of fredom, you think
%      to try an analytical solution, you have to enter initial
%      coordinate qj0 and initial velocity qtj0 as strings like this:
%         qj0  = 'q0';  ( or qj0  = '0.1';)
%         qtj0 = 'qt0'; ( or qtj0 = '7.0';)
%      After you have got the analytical solution and save it in a file,
%      you can immediately continue with the numerical solution. Than,
%      if qj0 and qtj0 have been symbols, you will be prompted to enter 
%      there numerical values!
%
% EXAMPLE of DATA FILE:
%  % Problem: Elliptical Pendulum
%    s = 2;                % Degree of freedom
%    L = ['1/2*(m1+m2)*qt1^2 + 1/2*m2*l^2*qt2^2 + ',...
%            'm2*l*qt1*qt2*cos(q2) - 1/2*c*q1^2 + ',...
%            '9.81*m2*l*cos(q2)']; % Lagrangean
%    QN{1} = '-alfa*qt1'; % Generalized
%    QN{2} = '-k*qt2';    % non potential forces
%    qj0   = [0.02, 0];   % Initial coordinates
%    qtj0  = [0.1, 0];    % Initial velocities
%    Tend  = 20;          % Upper bound of integration
%    eps   = 1.e-8;       % Precision of computations
%    np    = 6;           % Number of parameters
%    P{1}  = 'm1';        % Name assignation of the
%    P{2}  = 'm2';        % physical parameters
%    P{3}  = 'l';
%    P{4}  = 'c';
%    P{5}  = 'alfa';
%    P{6}  = 'k';